Release 0.1.0 - 2016/11/03
--------------------------

Feature
~~~~~~~

* `--ascii-output` option, that ensures ASCII characters (#37)
* `--raw-input` option, that treats inputs as raw strings instead of parsing JSON objects (#35, #36)
* `--join-output` option, that joins JSON strings and does not show new lines (#24, #33)
* `--raw-output` option, that print raw strings instead of JSON (#31, #32, #34)
* `--sort-key` option, that sorts keys in a JSON object (#27, #29)
* `--import` option, that imports Python module (#25, #26, #28, #30)
* `--version` option, that shows version number (#18, #20)

Bug
~~~

* Show an error message when an error happens (#17, #19)

Document
~~~~~~~~

* Fixed typo  (thank you @tgpfeiffer ! #22)
                  

Release 0.0.0 - 2016/10/15
--------------------------

First release
